pub enum InnerBody {
Control(ControlBody),
Original(OriginalBody),
Split(SplitBody),
}Variants
Implementations
Sourceimpl InnerBody
impl InnerBody
pub fn into_reliable(self, seqnum: WrappingSequenceNumber) -> PacketBody
pub fn into_unreliable(self) -> PacketBody
Sourcepub fn command(&self) -> Option<&Command>
pub fn command(&self) -> Option<&Command>
Get a reference to the Command this body contains, if any. If this is part of a split packet, None will be returned even though there is a fragment of a Command inside.
This doesn’t differentiate between a body which cannot have a command and a body which doesn’t have a command.